@@ -3215,25 +3215,45 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
             'type': int,
             'format': 'int64',
         },
+        'retransmission_timeout': {
+            'type': int,
+            'format': 'int64',
+        },
+        'congestion_window': {
+            'type': int,
+            'format': 'int64',
+        },
+        'slow_start_threshold': {
+            'type': int,
+            'format': 'int64',
+        },
+        'path_mtu': {
+            'type': int,
+            'format': 'int64',
+        },
     } # type: Dict[str, str]
 
     _REQUIRED= () # type: tuple(str)
 
     _DEFAULTS= {} # type: Dict[str, Union(type)]
 
-    def __init__(self, parent=None, rtt=None, rtt_variance=None, retransmissions=None):
+    def __init__(self, parent=None, rtt=None, rtt_variance=None, retransmissions=None, retransmission_timeout=None, congestion_window=None, slow_start_threshold=None, path_mtu=None):
         super(MetricsResponseFlowResultTcpInfo, self).__init__()
         self._parent = parent
         self._set_property('rtt', rtt)
         self._set_property('rtt_variance', rtt_variance)
         self._set_property('retransmissions', retransmissions)
+        self._set_property('retransmission_timeout', retransmission_timeout)
+        self._set_property('congestion_window', congestion_window)
+        self._set_property('slow_start_threshold', slow_start_threshold)
+        self._set_property('path_mtu', path_mtu)
 
     @property
     def rtt(self):
         # type: () -> int
         """rtt getter
 
-        round trip time in microseconds
+        average round trip time in microseconds
 
         Returns: int
         """
@@ -3243,7 +3263,7 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
     def rtt(self, value):
         """rtt setter
 
-        round trip time in microseconds
+        average round trip time in microseconds
 
         value: int
         """
@@ -3291,6 +3311,90 @@ class MetricsResponseFlowResultTcpInfo(OpenApiObject):
         """
         self._set_property('retransmissions', value)
 
+    @property
+    def retransmission_timeout(self):
+        # type: () -> int
+        """retransmission_timeout getter
+
+        retransmission timeout in micro seconds
+
+        Returns: int
+        """
+        return self._get_property('retransmission_timeout')
+
+    @retransmission_timeout.setter
+    def retransmission_timeout(self, value):
+        """retransmission_timeout setter
+
+        retransmission timeout in micro seconds
+
+        value: int
+        """
+        self._set_property('retransmission_timeout', value)
+
+    @property
+    def congestion_window(self):
+        # type: () -> int
+        """congestion_window getter
+
+        congestion windows size in bytes
+
+        Returns: int
+        """
+        return self._get_property('congestion_window')
+
+    @congestion_window.setter
+    def congestion_window(self, value):
+        """congestion_window setter
+
+        congestion windows size in bytes
+
+        value: int
+        """
+        self._set_property('congestion_window', value)
+
+    @property
+    def slow_start_threshold(self):
+        # type: () -> int
+        """slow_start_threshold getter
+
+        slow start threshold in bytes (max int64 value when wide open)
+
+        Returns: int
+        """
+        return self._get_property('slow_start_threshold')
+
+    @slow_start_threshold.setter
+    def slow_start_threshold(self, value):
+        """slow_start_threshold setter
+
+        slow start threshold in bytes (max int64 value when wide open)
+
+        value: int
+        """
+        self._set_property('slow_start_threshold', value)
+
+    @property
+    def path_mtu(self):
+        # type: () -> int
+        """path_mtu getter
+
+        path MTU
+
+        Returns: int
+        """
+        return self._get_property('path_mtu')
+
+    @path_mtu.setter
+    def path_mtu(self, value):
+        """path_mtu setter
+
+        path MTU
+
+        value: int
+        """
+        self._set_property('path_mtu', value)
+
 
 class MetricsResponseFlowResultIter(OpenApiIter):
     __slots__ = ('_parent', '_choice')
